"""
全局变量
"""

from numpy import array, ndarray
from pandas import Series

# 左乘行变换矩阵,将以左上角为原点的归一化数据转换为手部向量数据
# 按照手部骨骼将每个关节的关键点数据相减变成向量,向量数据存在被减数所在的行
T_NORM2VEC: ndarray = array(
    [
        [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0],
        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1],
    ],
)

# 左乘行变换矩阵,将以手腕关键点为原点的数据转换为以手部左上角为原点
# 行变换,将第0行手腕关键点数据加到后面的20个手腕关键点数据上,变回以手部左上角为原点的关键点数据
T_NORM2WRIST: ndarray = array(
    [
        [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0],
        [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1],
    ],
)

# 手部数据的列名
HAND_DATA_COL_NAME: Series = Series(
    (
        "norm_pos0_x",
        "norm_pos0_y",
        "norm_pos0_z",
        "norm_pos1_x",
        "norm_pos1_y",
        "norm_pos1_z",
        "norm_pos2_x",
        "norm_pos2_y",
        "norm_pos2_z",
        "norm_pos3_x",
        "norm_pos3_y",
        "norm_pos3_z",
        "norm_pos4_x",
        "norm_pos4_y",
        "norm_pos4_z",
        "norm_pos5_x",
        "norm_pos5_y",
        "norm_pos5_z",
        "norm_pos6_x",
        "norm_pos6_y",
        "norm_pos6_z",
        "norm_pos7_x",
        "norm_pos7_y",
        "norm_pos7_z",
        "norm_pos8_x",
        "norm_pos8_y",
        "norm_pos8_z",
        "norm_pos9_x",
        "norm_pos9_y",
        "norm_pos9_z",
        "norm_pos10_x",
        "norm_pos10_y",
        "norm_pos10_z",
        "norm_pos11_x",
        "norm_pos11_y",
        "norm_pos11_z",
        "norm_pos12_x",
        "norm_pos12_y",
        "norm_pos12_z",
        "norm_pos13_x",
        "norm_pos13_y",
        "norm_pos13_z",
        "norm_pos14_x",
        "norm_pos14_y",
        "norm_pos14_z",
        "norm_pos15_x",
        "norm_pos15_y",
        "norm_pos15_z",
        "norm_pos16_x",
        "norm_pos16_y",
        "norm_pos16_z",
        "norm_pos17_x",
        "norm_pos17_y",
        "norm_pos17_z",
        "norm_pos18_x",
        "norm_pos18_y",
        "norm_pos18_z",
        "norm_pos19_x",
        "norm_pos19_y",
        "norm_pos19_z",
        "norm_pos20_x",
        "norm_pos20_y",
        "norm_pos20_z",
        "p1_angle",
        "p2_angle",
        "p3_angle",
        "p5_angle",
        "p6_angle",
        "p7_angle",
        "p9_angle",
        "p10_angle",
        "p11_angle",
        "p13_angle",
        "p14_angle",
        "p15_angle",
        "p17_angle",
        "p18_angle",
        "p19_angle",
        "pos8_2thumb",
        "pos12_2thumb",
        "pos16_2thumb",
        "pos20_2thumb",
    )
)
